@@ -11,14 +11,17 @@ from director.models.utils import JSONBType
 class Task(BaseModel):
     __tablename__ = "tasks"
 
-    key = db.Column(db.String(), nullable=False)
+    key = db.Column(db.String(255), nullable=False)
     status = db.Column(db.Enum(StatusType), default=StatusType.pending, nullable=False)
     previous = db.Column(JSONBType, default=[])
     result = db.Column(PickleType)
 
     # Relationship
     workflow_id = db.Column(
-        UUIDType(binary=False), db.ForeignKey("workflows.id"), nullable=False
+        UUIDType(binary=False),
+        db.ForeignKey("workflows.id"),
+        nullable=False,
+        index=True,
     )
     workflow = db.relationship("Workflow", backref=db.backref("tasks", lazy=True))
 
