@@ -7,6 +7,7 @@ from environs import Env
 HIDDEN_CONFIG = [
     "DIRECTOR_ENABLE_DARK_THEME",
     "DIRECTOR_ENABLE_HISTORY_MODE",
+    "DIRECTOR_REFRESH_INTERVAL",
     "DIRECTOR_API_URL",
     "DIRECTOR_FLOWER_URL",
     "DIRECTOR_DATABASE_URI",
@@ -42,6 +43,7 @@ class Config(object):
         self.API_URL = env.str("DIRECTOR_API_URL", "http://127.0.0.1:8000/api")
         self.FLOWER_URL = env.str("DIRECTOR_FLOWER_URL", "http://127.0.0.1:5555")
         self.WORKFLOWS_PER_PAGE = env.int("DIRECTOR_WORKFLOWS_PER_PAGE", 1000)
+        self.REFRESH_INTERVAL = env.int("DIRECTOR_REFRESH_INTERVAL", 30000)
 
         # Authentication
         self.AUTH_ENABLED = env.bool("DIRECTOR_AUTH_ENABLED", False)
